syntax = "proto3";
package sentinel.node.v2;

import "cosmos/base/v1beta1/coin.proto";
import "gogoproto/gogo.proto";
import "google/protobuf/duration.proto";

option go_package            = "github.com/sentinel-official/hub/x/node/types";
option (gogoproto.equal_all) = false;
option (gogoproto.goproto_getters_all) = false;

message Params {
  cosmos.base.v1beta1.Coin deposit = 1 [ (gogoproto.nullable) = false ];
  google.protobuf.Duration inactive_duration = 2
      [ (gogoproto.nullable) = false, (gogoproto.stdduration) = true ];
  repeated cosmos.base.v1beta1.Coin max_gigabyte_prices = 3 [
    (gogoproto.nullable)     = false,
    (gogoproto.castrepeated) = "github.com/cosmos/cosmos-sdk/types.Coins"
  ];
  repeated cosmos.base.v1beta1.Coin min_gigabyte_prices = 4 [
    (gogoproto.nullable)     = false,
    (gogoproto.castrepeated) = "github.com/cosmos/cosmos-sdk/types.Coins"
  ];
  repeated cosmos.base.v1beta1.Coin max_hourly_prices = 5 [
    (gogoproto.nullable)     = false,
    (gogoproto.castrepeated) = "github.com/cosmos/cosmos-sdk/types.Coins"
  ];
  repeated cosmos.base.v1beta1.Coin min_hourly_prices = 6 [
    (gogoproto.nullable)     = false,
    (gogoproto.castrepeated) = "github.com/cosmos/cosmos-sdk/types.Coins"
  ];
  int64 max_subscription_gigabytes = 7;
  int64 min_subscription_gigabytes = 8;
  int64 max_subscription_hours     = 9;
  int64 min_subscription_hours     = 10;
  string staking_share             = 11 [
    (gogoproto.customtype) = "github.com/cosmos/cosmos-sdk/types.Dec",
    (gogoproto.nullable)   = false
  ];
}
