syntax = "proto3";
package cosmos.crypto.multisig.v1beta1;

import "gogoproto/gogo.proto";

option go_package = "github.com/cosmos/cosmos-sdk/crypto/types";

// MultiSignature wraps the signatures from a multisig.LegacyAminoPubKey.
// See cosmos.tx.v1betata1.ModeInfo.Multi for how to specify which signers
// signed and with which modes.
message MultiSignature {
  option (gogoproto.goproto_unrecognized) = true;
  repeated bytes signatures               = 1;
}

// CompactBitArray is an implementation of a space efficient bit array.
// This is used to ensure that the encoded data takes up a minimal amount of
// space after proto encoding.
// This is not thread safe, and is not intended for concurrent usage.
message CompactBitArray {
  option (gogoproto.goproto_stringer) = false;

  uint32 extra_bits_stored = 1;
  bytes  elems             = 2;
}
