syntax = "proto3";
package sentinel.subscription.v2;

import "cosmos/base/v1beta1/coin.proto";
import "gogoproto/gogo.proto";
import "google/protobuf/timestamp.proto";

option go_package = "github.com/sentinel-official/hub/x/subscription/types";
option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message Payout {
  uint64 id                           = 1 [ (gogoproto.customname) = "ID" ];
  string address                      = 2;
  string node_address                 = 3;
  int64 hours                         = 4;
  cosmos.base.v1beta1.Coin price      = 5 [ (gogoproto.nullable) = false ];
  google.protobuf.Timestamp timestamp = 6
      [ (gogoproto.nullable) = false, (gogoproto.stdtime) = true ];
}
