syntax = "proto3";
package sentinel.session.v2;

import "gogoproto/gogo.proto";
import "google/protobuf/duration.proto";

option go_package = "github.com/sentinel-official/hub/x/session/types";
option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message Params {
  google.protobuf.Duration inactive_duration = 1
      [ (gogoproto.nullable) = false, (gogoproto.stdduration) = true ];
  bool proof_verification_enabled = 2;
}
