syntax = "proto3";
package cosmos.crypto.multisig;

import "gogoproto/gogo.proto";
import "google/protobuf/any.proto";

option go_package = "github.com/cosmos/cosmos-sdk/crypto/keys/multisig";

// LegacyAminoPubKey specifies a public key type
// which nests multiple public keys and a threshold,
// it uses legacy amino address rules.
message LegacyAminoPubKey {
  option (gogoproto.goproto_getters) = false;

  uint32   threshold                       = 1 [(gogoproto.moretags) = "yaml:\"threshold\""];
  repeated google.protobuf.Any public_keys = 2
      [(gogoproto.customname) = "PubKeys", (gogoproto.moretags) = "yaml:\"pubkeys\""];
}
