syntax = "proto3";
package tendermint.p2p;

option go_package = "github.com/tendermint/tendermint/proto/tendermint/p2p";

import "tendermint/p2p/types.proto";
import "gogoproto/gogo.proto";

message PexRequest {}

message PexAddrs {
  repeated NetAddress addrs = 1 [(gogoproto.nullable) = false];
}

message Message {
  oneof sum {
    PexRequest pex_request = 1;
    PexAddrs   pex_addrs   = 2;
  }
}
