syntax = "proto3";
package cosmos.base.kv.v1beta1;

import "gogoproto/gogo.proto";

option go_package = "github.com/cosmos/cosmos-sdk/types/kv";

// Pairs defines a repeated slice of Pair objects.
message Pairs {
  repeated Pair pairs = 1 [(gogoproto.nullable) = false];
}

// Pair defines a key/value bytes tuple.
message Pair {
  bytes key   = 1;
  bytes value = 2;
}
