syntax = "proto3";
package sentinel.provider.v2;

import "gogoproto/gogo.proto";
import "cosmos/base/v1beta1/coin.proto";

option go_package = "github.com/sentinel-official/hub/x/provider/types";
option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message Params {
  cosmos.base.v1beta1.Coin deposit = 1 [ (gogoproto.nullable) = false ];
  string staking_share             = 2 [
    (gogoproto.customtype) = "github.com/cosmos/cosmos-sdk/types.Dec",
    (gogoproto.nullable)   = false
  ];
}
