syntax = "proto3";
package sentinel.swap.v1;

option go_package = "github.com/sentinel-official/hub/x/swap/types";

import "gogoproto/gogo.proto";

option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

// MsgSwapRequest defines the SDK message for swapping an ERC-20 token to the
// native coin
message MsgSwapRequest {
  string frm     = 1;
  bytes tx_hash   = 2;
  string receiver = 3;
  string amount   = 4 [
    (gogoproto.customtype) = "github.com/cosmos/cosmos-sdk/types.Int",
    (gogoproto.nullable)   = false
  ];
}

// MsgSwapResponse defines the response of message MsgSwapRequest
message MsgSwapResponse {}

service MsgService { rpc MsgSwap(MsgSwapRequest) returns (MsgSwapResponse); }
